package com.taais.biz.service.impl;

import java.util.Arrays;
import java.util.List;

import cn.hutool.core.util.ObjectUtil;
import com.mybatisflex.core.paginate.Page;
import com.mybatisflex.core.query.QueryWrapper;
import com.taais.common.core.utils.MapstructUtils;
import com.taais.common.core.utils.StringUtils;
import com.taais.common.orm.core.page.PageQuery;
import com.taais.common.core.core.page.PageResult;
import com.taais.common.orm.core.service.impl.BaseServiceImpl;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.taais.biz.mapper.AlgorithmModelTrackMapper;
import com.taais.biz.domain.AlgorithmModelTrack;
import com.taais.biz.domain.bo.AlgorithmModelTrackBo;
import com.taais.biz.domain.vo.AlgorithmModelTrackVo;
import com.taais.biz.service.IAlgorithmModelTrackService;
import static com.taais.biz.domain.table.AlgorithmModelTrackTableDef.ALGORITHM_MODEL_TRACK;

/**
 * 算法模型配置Service业务层处理
 *
 * @author wangkang
 * 2024-09-26
 */
@Service
public class AlgorithmModelTrackServiceImpl extends BaseServiceImpl<AlgorithmModelTrackMapper, AlgorithmModelTrack> implements IAlgorithmModelTrackService {
    @Resource
    private AlgorithmModelTrackMapper algorithmModelTrackMapper;

    @Override
    public QueryWrapper query() {
        return super.query().from(ALGORITHM_MODEL_TRACK);
    }

    private QueryWrapper buildQueryWrapper(AlgorithmModelTrackBo algorithmModelTrackBo) {
        QueryWrapper queryWrapper = super.buildBaseQueryWrapper();
        queryWrapper.and(ALGORITHM_MODEL_TRACK.ALGORITHM_ID.eq
        (algorithmModelTrackBo.getAlgorithmId()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.MODEL_NAME.like
        (algorithmModelTrackBo.getModelName()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.MODEL_ADDRESS.eq
        (algorithmModelTrackBo.getModelAddress()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.SAMPLE_NUMBER.eq
        (algorithmModelTrackBo.getSampleNumber()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.CYCLE_EPOCH.eq
        (algorithmModelTrackBo.getCycleEpoch()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.REMARKS.eq
        (algorithmModelTrackBo.getRemarks()));
        queryWrapper.and(ALGORITHM_MODEL_TRACK.SYSTEM.eq
        (algorithmModelTrackBo.getSystem()));

        return queryWrapper;
    }

    /**
     * 查询算法模型配置
     *
     * @param id 算法模型配置主键
     * @return 算法模型配置
     */
    @Override
    public AlgorithmModelTrackVo selectById(Long id) {
            return this.getOneAs(query().where(ALGORITHM_MODEL_TRACK.ID.eq(id)), AlgorithmModelTrackVo.class);

    }

    /**
     * 查询算法模型配置列表
     *
     * @param algorithmModelTrackBo 算法模型配置Bo
     * @return 算法模型配置集合
     */
    @Override
    public List<AlgorithmModelTrackVo> selectList(AlgorithmModelTrackBo algorithmModelTrackBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(algorithmModelTrackBo);
            return this.listAs(queryWrapper, AlgorithmModelTrackVo.class);
    }

    /**
     * 分页查询算法模型配置列表
     *
     * @param algorithmModelTrackBo 算法模型配置Bo
     * @return 分页算法模型配置集合
     */
    @Override
    public PageResult<AlgorithmModelTrackVo> selectPage(AlgorithmModelTrackBo algorithmModelTrackBo) {
        QueryWrapper queryWrapper = buildQueryWrapper(algorithmModelTrackBo);
            Page<AlgorithmModelTrackVo> page = this.pageAs(PageQuery.build(), queryWrapper, AlgorithmModelTrackVo.class);
        return PageResult.build(page);
    }

    /**
     * 新增算法模型配置
     *
     * @param algorithmModelTrackBo 算法模型配置Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    @Override
    public boolean insert(AlgorithmModelTrackBo algorithmModelTrackBo) {
    AlgorithmModelTrack algorithmModelTrack =MapstructUtils.convert(algorithmModelTrackBo, AlgorithmModelTrack. class);

        return this.save(algorithmModelTrack);//使用全局配置的雪花算法主键生成器生成ID值
    }

    /**
     * 修改算法模型配置
     *
     * @param algorithmModelTrackBo 算法模型配置Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    @Override
    public boolean update(AlgorithmModelTrackBo algorithmModelTrackBo) {
        AlgorithmModelTrack algorithmModelTrack =MapstructUtils.convert(algorithmModelTrackBo, AlgorithmModelTrack. class);
        if (ObjectUtil.isNotNull(algorithmModelTrack) && ObjectUtil.isNotNull(algorithmModelTrack.getId())){
            boolean updated = this.updateById(algorithmModelTrack);
                return updated;
        }
        return false;
    }

    /**
     * 批量删除算法模型配置
     *
     * @param ids 需要删除的算法模型配置主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    @Transactional
    @Override
    public boolean deleteByIds(Long[] ids) {
        return this.removeByIds(Arrays.asList(ids));
    }

}
